/*
 * Copyright (C) 2022-2023 luca0N!
 *
 * This file is part of Static Website Generator (swg).
 *
 * Static Website Generator (swg) is free software: you can redistribute it
 * and/or modify it under the terms of the version 3 of the GNU Lesser General
 * Public License as published by the Free Software Foundation.
 *
 * Static Website Generator (swg) is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Static Website Generator (swg). If not, see
 * <https://www.gnu.org/licenses/>.
 *
 * Contact luca0N! by e-mail: <luca0n [at] luca0n [dot] com>. 
 */

#include "Common.hxx"

#include <iostream>
#include <fstream>

const char* HR_MONTH[] = {
	"January",
	"February",
	"March",
	"April",
	"May",
	"June",
	"July",
	"August",
	"September",
	"October",
	"November",
	"December"
};

const char* get_hr_month(unsigned short month) {
		return HR_MONTH[month];
}

std::string getFilename(std::string const &path, bool const ext) {
	int extSeparator = -1;
	// Backwards search for directory separator.
	for (int x = path.length(); x > 0; --x) {
		if (path[x] == '/') return ext ? path.substr(x + 1) : path.substr(x + 1, extSeparator - x - 1);
		// If this function was called with "ext" set to false,
		// generate a substring of the path containing the filename
		// only.
		else if (!ext && path[x] == '.' && extSeparator == -1)
			extSeparator = x;
	}
	return path;
}

std::filesystem::path get_output_path(std::string const &path) {
	std::filesystem::path output = path;
	return output /= "output";
}

/**
 * Used to determine whether a file should be copied onto the output directory
 * or not.  Certain files, like the config file shouldn't be copied.
 */
bool is_special_file(std::string const &filename) {
	if (filename == "swg.cfg" || filename.find("__swg_") == 0)
		return true;
	return false;
}

std::string get_template(std::string const &path) {
	std::string filePath = path;
	// Template lookup
	filePath += "/__swg_template.html";
	if (!std::filesystem::exists(filePath)) {
		std::cerr << "error: couldn't find the SWG HTML template file.\n";
		exit(RETURN_FAILED_INVALID_DIRECTORY);
	}

	std::string htmlTemplate;
	std::ifstream swgTemplate(filePath);
	for (std::string line; std::getline(swgTemplate, line);) {
		htmlTemplate += line;
		if (!swgTemplate.eof())
			htmlTemplate += '\n';
	}

	if (verbose) std::cout << "Loaded HTML template into memory.\n";
	return htmlTemplate;
}

